pub enum IReceivePolicyGuardErrors {
InvalidReceipt(InvalidReceipt),
InvalidClaimAddress(InvalidClaimAddress),
UnauthorizedClaimer(UnauthorizedClaimer),
AddressReserved(AddressReserved),
}Expand description
Container for all the IReceivePolicyGuard custom errors.
Variants
InvalidReceipt(InvalidReceipt)
InvalidClaimAddress(InvalidClaimAddress)
AddressReserved(AddressReserved)
Implementations
Sourceimpl IReceivePolicyGuardErrors
impl IReceivePolicyGuardErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl IReceivePolicyGuardErrors
impl IReceivePolicyGuardErrors
Sourcepub fn invalid_receipt() -> Self
pub fn invalid_receipt() -> Self
Creates a InvalidReceipt error.
error InvalidReceipt()Sourcepub fn invalid_claim_address() -> Self
pub fn invalid_claim_address() -> Self
Creates a InvalidClaimAddress error.
error InvalidClaimAddress()Creates a UnauthorizedClaimer error.
error UnauthorizedClaimer()Sourcepub fn address_reserved() -> Self
pub fn address_reserved() -> Self
Creates a AddressReserved error.
error AddressReserved()Trait Implementations
Sourceimpl Clone for IReceivePolicyGuardErrors
impl Clone for IReceivePolicyGuardErrors
Sourcefn clone(&self) -> IReceivePolicyGuardErrors
fn clone(&self) -> IReceivePolicyGuardErrors
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for IReceivePolicyGuardErrors
impl Debug for IReceivePolicyGuardErrors
Sourceimpl<'de> Deserialize<'de> for IReceivePolicyGuardErrors
impl<'de> Deserialize<'de> for IReceivePolicyGuardErrors
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for IReceivePolicyGuardErrors
Sourceimpl PartialEq for IReceivePolicyGuardErrors
impl PartialEq for IReceivePolicyGuardErrors
Sourcefn eq(&self, other: &IReceivePolicyGuardErrors) -> bool
fn eq(&self, other: &IReceivePolicyGuardErrors) -> bool
self and other values to be equal, and is used by ==.Sourceimpl SolInterface for IReceivePolicyGuardErrors
impl SolInterface for IReceivePolicyGuardErrors
Sourceconst MIN_DATA_LENGTH: usize = 0usize
const MIN_DATA_LENGTH: usize = 0usize
Sourcefn valid_selector(selector: [u8; 4]) -> bool
fn valid_selector(selector: [u8; 4]) -> bool
true if the given selector is known to this type.Sourcefn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
self.Sourcefn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
self, with validation. Read moreSourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
self into the given buffer, without any selectors.fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
self into the given buffer.fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
self.fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
self, with validation. Read moreimpl StructuralPartialEq for IReceivePolicyGuardErrors