pub struct ReceiptClaimed {
pub token: Address,
pub receiver: Address,
pub blockedNonce: u64,
pub blockedAt: u64,
pub receiptVersion: u8,
pub originator: Address,
pub recipient: Address,
pub recoveryAuthority: Address,
pub caller: Address,
pub to: Address,
pub amount: U256,
}Expand description
@notice Emitted when blocked funds are claimed with a valid receipt.
@param token TIP-20 token released by the guard.
@param receiver Resolved account where funds would settle; for virtual recipients its their master.
@param blockedNonce Guard nonce from the claimed receipt.
@param blockedAt Block timestamp from the claimed receipt.
@param receiptVersion Claim receipt layout version.
@param originator Original sender/originator from the claimed receipt.
@param recipient Addressed recipient from the claimed receipt; may be virtual.
@param recoveryAuthority Claim authority from the claimed receipt.
@param caller Account that submitted the claim.
@param to Address where released funds were sent.
@param amount Amount of funds released.
Event with signature ReceiptClaimed(address,address,uint64,uint64,uint8,address,address,address,address,address,uint256) and selector 0xdfa88f3774430fdb1d282219332a663236ccc8035ba8b9e0df856b374a5db085.
event ReceiptClaimed(address indexed token, address indexed receiver, uint64 indexed blockedNonce, uint64 blockedAt, uint8 receiptVersion, address originator, address recipient, address recoveryAuthority, address caller, address to, uint256 amount);Fields
token: Addressreceiver: AddressblockedNonce: u64blockedAt: u64receiptVersion: u8originator: Addressrecipient: AddressrecoveryAuthority: Addresscaller: Addressto: Addressamount: U256Trait Implementations
Sourceimpl Clone for ReceiptClaimed
impl Clone for ReceiptClaimed
Sourcefn clone(&self) -> ReceiptClaimed
fn clone(&self) -> ReceiptClaimed
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ReceiptClaimed
impl Debug for ReceiptClaimed
Sourceimpl<'de> Deserialize<'de> for ReceiptClaimed
impl<'de> Deserialize<'de> for ReceiptClaimed
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for ReceiptClaimed
Sourceimpl From<&ReceiptClaimed> for LogData
impl From<&ReceiptClaimed> for LogData
Sourcefn from(this: &ReceiptClaimed) -> LogData
fn from(this: &ReceiptClaimed) -> LogData
Sourceimpl IntoLogData for ReceiptClaimed
impl IntoLogData for ReceiptClaimed
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.Sourceimpl JsonAbiExt for ReceiptClaimed
impl JsonAbiExt for ReceiptClaimed
Sourceimpl PartialEq for ReceiptClaimed
impl PartialEq for ReceiptClaimed
Sourcefn eq(&self, other: &ReceiptClaimed) -> bool
fn eq(&self, other: &ReceiptClaimed) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ReceiptClaimed
impl Serialize for ReceiptClaimed
Sourceimpl SolEvent for ReceiptClaimed
impl SolEvent for ReceiptClaimed
Sourceconst SIGNATURE: &'static str = "ReceiptClaimed(address,address,uint64,uint64,uint8,address,address,address,address,address,uint256)"
const SIGNATURE: &'static str = "ReceiptClaimed(address,address,uint64,uint64,uint8,address,address,address,address,address,uint256)"
Sourceconst SIGNATURE_HASH: B256
const SIGNATURE_HASH: B256
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Uint<64>, Uint<8>, Address, Address, Address, Address, Address, Uint<256>)
type DataTuple<'a> = (Uint<64>, Uint<8>, Address, Address, Address, Address, Address, Uint<256>)
Sourcetype DataToken<'a> = <<ReceiptClaimed as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<ReceiptClaimed as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
TokenSeq] type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>, Address, Address, Uint<64>)
type TopicList = (FixedBytes<32>, Address, Address, Uint<64>)
Sourcefn new(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Self
fn new( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Self
Sourcefn check_signature(
topics: &<Self::TopicList as SolType>::RustType,
) -> Result<()>
fn check_signature( topics: &<Self::TopicList as SolType>::RustType, ) -> Result<()>
Sourcefn tokenize_body(&self) -> Self::DataToken<'_>
fn tokenize_body(&self) -> Self::DataToken<'_>
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn new_checked(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Result<Self, Error>
fn new_checked( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Result<Self, Error>
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
fn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data(&self) -> Vec<u8> ⓘ
fn encode_data(&self) -> Vec<u8> ⓘ
fn encode_topics(&self) -> Vec<WordToken>
fn encode_topics(&self) -> Vec<WordToken>
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_log_data(&self) -> LogData
fn encode_log_data(&self) -> LogData
LogData].fn encode_log(log: &Log<Self>) -> Log
fn encode_log(log: &Log<Self>) -> Log
Log] containing this event into a [Log] containing
[LogData].fn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn abi_decode_data<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log_validate(log: &Log) -> Result<Log<Self>, Error>
fn decode_log_validate(log: &Log) -> Result<Log<Self>, Error>
impl StructuralPartialEq for ReceiptClaimed