pub struct TransferBlocked {
pub token: Address,
pub receiver: Address,
pub blockedNonce: u64,
pub amount: U256,
pub receiptVersion: u8,
pub receipt: Bytes,
}Expand description
@notice Emitted when an inbound TIP-20 transfer or mint is blocked and funds are redirected.
@param token TIP-20 token whose funds are held by the guard.
@param receiver Resolved account where funds would settle; for virtual recipients its their master.
@param blockedNonce Guard nonce assigned to the blocked operation.
@param amount Amount of blocked funds held by the guard.
@param receiptVersion Claim receipt layout version.
@param receipt ABI-encoded receipt witness that can be passed to claim.
Event with signature TransferBlocked(address,address,uint64,uint256,uint8,bytes) and selector 0x361d86e46fd139dc3eac4148f16b53597f0f8ddd9aba772aae0034bda5531b1c.
event TransferBlocked(address indexed token, address indexed receiver, uint64 indexed blockedNonce, uint256 amount, uint8 receiptVersion, bytes receipt);Fields
token: Addressreceiver: AddressblockedNonce: u64amount: U256receiptVersion: u8receipt: BytesTrait Implementations
Sourceimpl Clone for TransferBlocked
impl Clone for TransferBlocked
Sourcefn clone(&self) -> TransferBlocked
fn clone(&self) -> TransferBlocked
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TransferBlocked
impl Debug for TransferBlocked
Sourceimpl<'de> Deserialize<'de> for TransferBlocked
impl<'de> Deserialize<'de> for TransferBlocked
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for TransferBlocked
Sourceimpl From<&TransferBlocked> for LogData
impl From<&TransferBlocked> for LogData
Sourcefn from(this: &TransferBlocked) -> LogData
fn from(this: &TransferBlocked) -> LogData
Sourceimpl IntoLogData for TransferBlocked
impl IntoLogData for TransferBlocked
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.Sourceimpl JsonAbiExt for TransferBlocked
impl JsonAbiExt for TransferBlocked
Sourceimpl PartialEq for TransferBlocked
impl PartialEq for TransferBlocked
Sourcefn eq(&self, other: &TransferBlocked) -> bool
fn eq(&self, other: &TransferBlocked) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TransferBlocked
impl Serialize for TransferBlocked
Sourceimpl SolEvent for TransferBlocked
impl SolEvent for TransferBlocked
Sourceconst SIGNATURE: &'static str = "TransferBlocked(address,address,uint64,uint256,uint8,bytes)"
const SIGNATURE: &'static str = "TransferBlocked(address,address,uint64,uint256,uint8,bytes)"
Sourceconst SIGNATURE_HASH: B256
const SIGNATURE_HASH: B256
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Uint<256>, Uint<8>, Bytes)
type DataTuple<'a> = (Uint<256>, Uint<8>, Bytes)
Sourcetype DataToken<'a> = <<TransferBlocked as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<TransferBlocked as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
TokenSeq] type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>, Address, Address, Uint<64>)
type TopicList = (FixedBytes<32>, Address, Address, Uint<64>)
Sourcefn new(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Self
fn new( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Self
Sourcefn check_signature(
topics: &<Self::TopicList as SolType>::RustType,
) -> Result<()>
fn check_signature( topics: &<Self::TopicList as SolType>::RustType, ) -> Result<()>
Sourcefn tokenize_body(&self) -> Self::DataToken<'_>
fn tokenize_body(&self) -> Self::DataToken<'_>
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn new_checked(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Result<Self, Error>
fn new_checked( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Result<Self, Error>
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
fn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data(&self) -> Vec<u8> ⓘ
fn encode_data(&self) -> Vec<u8> ⓘ
fn encode_topics(&self) -> Vec<WordToken>
fn encode_topics(&self) -> Vec<WordToken>
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_log_data(&self) -> LogData
fn encode_log_data(&self) -> LogData
LogData].fn encode_log(log: &Log<Self>) -> Log
fn encode_log(log: &Log<Self>) -> Log
Log] containing this event into a [Log] containing
[LogData].fn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn abi_decode_data<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log_validate(log: &Log) -> Result<Log<Self>, Error>
fn decode_log_validate(log: &Log) -> Result<Log<Self>, Error>
impl StructuralPartialEq for TransferBlocked